﻿// 作図コントロール
var drawControl;

// 作図レイヤのSakuzuListItem
var sakuzuListItem;

// 作図の初期化
function initSakuzu() {

    // KML、作図レイヤ管理クラス
    GSI.GLOBALS.sakuzuList = new GSI.SakuzuList(map, null, {}, {});

    // 作図レイヤを取り出す
    sakuzuListItem = GSI.GLOBALS.sakuzuList.getSakuzuItem();
    var sakuzuLayer = sakuzuListItem._layer;

    // 作図ツールバーの初期化
    initDrawToolbar();

    // 図形を描くためのコントローラを配置
    drawControl = new L.Control.Draw({
        position: 'topright',    // 位置のデフォルトは左上

        draw: {
            polyline: false,
            polygon: {
                shapeOptions: {
                    weight: 3,          // 線幅
                    color: '#000000',   // 線の色
                    opacity: 0.5,       // 線の透過度
                    fill: true,
                    fillColor: '#ff0000',     // 塗りつぶし色
                    fillOpacity: 0.5    // 塗りつぶしの透過度
                },
            },
            rectangle: false,
            circle: false,
            marker: {
                icon: L.icon({
                    iconUrl: 'http://cyberjapan.jp/symbols/080.png',
                    iconSize: [20, 20], // size of the icon
                    iconAnchor: [10, 10], // point of the icon which will correspond to marker's location
                    popupAnchor: [0, -10] // point from which the popup should open relative to the iconAnchor
                })
            }
        },

        edit: {
            featureGroup: sakuzuLayer,
            edit: true,
            remove: true
        }
    }).addTo(map);

    // 描き終わった時にレイヤーに追加
    map.on('draw:created', function (e) {

        var feature = e.layer;

        // 作図レイヤーに追加
        sakuzuLayer.addLayer(feature);

        // 属性入力ダイアログを表示
        $("#inputvalue").val('');
        $("#sakuzu_attribute_dialog").dialog({
            modal: true,
            title: '属性入力',
            buttons: {
                "OK": function () {
                    $(this).dialog("close");

                    var attribute = $("#inputvalue").val();
                    if (attribute != '') {
                        // KML出力のため、図形の属性に入れる
                        feature.feature = {};
                        feature.feature.properties = { name: attribute };

                        // ポップアップをつける
                        feature.bindPopup('<h2>' + GSI.Utils.encodeHTML(attribute) + '</h2>');
                    }
                },
                "キャンセル": function () {
                    $(this).dialog("close");
                    //alert('作図キャンセル');
                    sakuzuLayer.removeLayer(feature);
                }
            }
        });
    });
}

// 作図ツールバーの初期化
function initDrawToolbar() {

    L.drawLocal.draw.toolbar = {
        actions: {
            title: '描画キャンセル',
            text: 'キャンセル'
        },
        finish: {
            title: '描画終了',
            text: '終了'
        },
        undo: {
            title: '最後の点を削除',
            text: '最後の点を削除'
        },
        buttons: {
            polyline: 'ライン描画',
            polygon: 'ポリゴン描画',
            rectangle: '矩形描画',
            circle: '円形描画',
            marker: 'マーカー描画'
        }
    };

    L.drawLocal.draw.handlers.marker = {
        tooltip: {
            start: 'マーカーを置くポイントをクリック'
        }
    };

    L.drawLocal.draw.handlers.polygon = {
        tooltip: {
            start: '開始位置を選択',
            cont: '次の位置を選択',
            end: '次の位置を選択(最終点を2回クリックして終了)'
        }
    };

    L.drawLocal.edit = {
        toolbar: {
            actions: {
                save: {
                    title: '変更を保存',
                    text: '保存'
                },
                cancel: {
                    title: '変更を破棄',
                    text: 'キャンセル'
                }
            },
            buttons: {
                edit: '図形編集',
                editDisabled: '編集できる図形がありません',
                remove: '図形削除',
                removeDisabled: '削除できる図形がありません'
            }
        },
        handlers: {
            edit: {
                tooltip: {
                    text: '頂点やポイント位置を変更できます',
                    subtext: '変更を取り消すにはキャンセルをクリックしてください'
                }
            },
            remove: {
                tooltip: {
                    text: '削除する図形をクリック'
                }
            }
        }
    };
}
