﻿// 指定URLの地図を表示。既に地図が表示済みならば、破棄して作り直す
// in: 地図のURL、緯度、経度、ZL（ズームレベル）
function mapInitMap(url, lat, lon, zoom) {

    if (map) {
        map.remove();
    }
    map = createMap(url, lat, lon, zoom);
    layers = [];

    sendLocation();

    initSakuzu();
}

function mapSetNewBaseLayer(url) {
    baseLayer.setUrl(url);
}

// 指定キーのレイヤーに、指定のオブジェクトを配置する
// in: レイヤーID、オブジェクト（JSON文字列）、ドラッグ可能フラグ
// {"f":[{"key":key1,"lon":lon,"lat":lat},{"key":key2,"lon":lon,"lat":lat},…]}
function mapAddFeature(layerKey, layerType, dataStr) {

    if (!isExistLayer(layerKey)) {
        addLayer(layerKey);
    }

    var datas = JSON.parse(dataStr);


    for (var i = 0; i < datas.f.length; i++) {
        var data = datas.f[i];
        
        // すでに同IDのfeatureが存在するならば削除する
        if (isExistFeature(layerKey, data.key)) {
            removeFeature(layerKey, data.key);
        }

        // feature追加
        addFeature(layerKey, layerType, data.key, data.lat, data.lon, data);
    }
}

// レイヤーを破棄する
// in: レイヤーID
function mapRemoveLayer(layerKey) {
    if (!isExistLayer(layerKey)) {
        return;
    }

    removeLayer(layerKey);
}

function mapShowRaster(path, north, west, south, east) {
    var southWest = L.latLng(south, west),
        northEast = L.latLng(north, east),
        bounds = L.latLngBounds(southWest, northEast);

    if (rasterLayer) {
        map.removeLayer(rasterLayer);
    }

    rasterLayer = L.imageOverlay(path, bounds);
    rasterLayer.addTo(map);
    rasterLayer.bringToBack();
}

// ラスタレイヤーを破棄する
function mapRemoveRaster() {
    if (rasterLayer) {
        map.removeLayer(rasterLayer);
        rasterLayer = null;
    }
}

// 地図を指定の範囲に移動する
// in: 緯度1、経度1、緯度2、経度2
function mapFitMap(lat1, lon1, lat2, lon2) {
    map.fitBounds([[lat1, lon1], [lat2, lon2]]);
}

// 作図コントロールの表示/非表示を切り替える
// in: trueなら表示、falseなら非表示にする
function mapShowSakuzuControl(visible) {
    if (visible) {
        if (!drawControl._map) {
            drawControl.addTo(map);
        }
    } else {
        if (drawControl._map) {
            drawControl.removeFrom(map);
        }
    }
}

// 地図を指定の座標に移動する
function panMap(lat, lon) {
    map.panTo(new L.LatLng(lat, lon));
}

// KMLレイヤーの表示/非表示状態を取得する
function mapIsKmlLayerOn() {
    if (GSI.GLOBALS.sakuzuList.getLength() < 2) {
        // KMLレイヤーなし
        return false;
    }

    // 1つ目のKMLレイヤーの表示状態を返す
    return GSI.GLOBALS.sakuzuList.get(1).getVisible();
}

// KMLレイヤーの表示/非表示を切り替える
// in: trueなら表示、falseなら非表示にする
function mapShowKmlLayer(visible) {
    for (var i = 1; i < GSI.GLOBALS.sakuzuList.getLength() ; i++) {
        GSI.GLOBALS.sakuzuList.get(i).setVisible(visible);
    }
}

// KMLレイヤーの透過度を設定
// in: 透過度。0～1。
function mapSetKmlLayerOpacity(opacity) {
    var opacitySetter = new GSI.LayerOpacitySetter();
    for (var i = 1; i < GSI.GLOBALS.sakuzuList.getLength() ; i++) {
        opacitySetter.setOpacity(GSI.GLOBALS.sakuzuList.get(i)._layer, opacity);
    }
}

// KMLレイヤーがあるか
// return: あればtrue、なければfalse
function mapHasKmlLayer() {
    return GSI.GLOBALS.sakuzuList.getLength() > 1;
}

// KML入力
// in: ファイル名、KMLの内容
// return: 読み込めたかどうか
function mapInputKML(fileName, xmlDoc, opacity) {
    try {
        var item = GSI.GLOBALS.sakuzuList._loadKML(fileName, xmlDoc);
        if (!item) {
            return false;
        }
        try {
            if (item && item._layer && item._layer.getBounds) {
                map.fitBounds(item._layer.getBounds());
            }
        }
        catch (e) { }
    } catch (e) {
        return false;
    }

    // KMLレイヤーを全て表示ONにする
    mapShowKmlLayer(true);

    // 透過度設定
    mapSetKmlLayerOpacity(opacity);

    return true;
}

// KMLクリア
function mapUnloadKml() {
    for (var i = GSI.GLOBALS.sakuzuList.getLength() - 1; i > 0 ; i--) {
        GSI.GLOBALS.sakuzuList.removeByIndex(i);
    }
}

// 作図情報があるか
// return: あればtrue、なければfalse
function mapHasSakuzu() {
    return 0 < sakuzuListItem.getLayerCount();
}

// 作図KML出力
// return: KML文字列
function mapCreateSakuzuKML() {
    return GSI.GLOBALS.sakuzuList.toKML();
}
